
import setuptools

setuptools.setup(
    name="smart-hg-34",
    version="1.0",
    packages=setuptools.find_packages(),
    install_requires=['seaborn==0.8.1', 'scikit-learn==0.18.2', 'numpy==1.16.6', 'matplotlib==2.1.2'],
)
